@@ -4,6 +4,7 @@
 #'
 #' @param try logical: Should the body of the function be wrapped by the function \code{\link[base]{try}}? See details.
 #' @param timeout positive numeric or \code{Inf}: The number of seconds to wait for a response from the NSO server. Can not be less than 1 ms or 0.001 s.
+#' @param na.rm logical: If \code{TRUE}, it removes empty rows in a data frame which is result of this function.
 #'
 #' @details The NSO server returns "HTTP error 500" frequently. Due to the server error, error handling is supported. if \code{try} is \code{TRUE}, you have to write code with error handling as shown in the example.
 #'
@@ -34,9 +35,9 @@
 #' @seealso \link{get_table}, \link{get_table_info}, \link{get_sector_info}
 #' @references \url{http://opendata.1212.mn/en/doc/Api/GET-api-Itms}
 
-all_tables <- function (try = FALSE, timeout = Inf) {
+all_tables <- function (try = FALSE, timeout = Inf, na.rm = FALSE) {
 
-  expr = expression({
+  expr <- expression({
     url <- "http://opendata.1212.mn/"
     path <- "api/Itms"
     query <- list(type = "json")
@@ -48,7 +49,11 @@ all_tables <- function (try = FALSE, timeout = Inf) {
     if (response$status_code != 200) {
       stop(paste0("HTTP status code: ", response$status_code))
     }
-    jsonlite::fromJSON(rawToChar(response$content))
+    all.tables <- jsonlite::fromJSON(rawToChar(response$content))
+    if (na.rm) {
+      all.tables <- stats::na.omit(all.tables)
+    }
+    all.tables
   })
   if (try) {
     return(try(expr = eval(expr), silent = TRUE))
